
# TIMERS

## A timer library.

A timer library currently supporting the following modules

 * `heap` - Very efficient timer heap timers. Supports thousands of
   timers using a single python thread based timer.
